@@ -10,8 +10,8 @@ extern crate log;
 #[macro_use]
 extern crate serde;
 
-mod acc_tracker;
 mod account;
+mod account_tracker;
 mod config;
 mod cornish_fisher;
 mod errors;
@@ -24,9 +24,10 @@ mod position;
 mod utils;
 mod validator;
 
-pub use acc_tracker::AccTracker;
-pub use acc_tracker::ReturnsSource;
+use std::fmt::Formatter;
+
 pub use account::Account;
+pub use account_tracker::{AccountTracker, FullAccountTracker, NoAccountTracker, ReturnsSource};
 pub use config::Config;
 pub use errors::{Error, OrderError, Result};
 pub use exchange::Exchange;
@@ -34,8 +35,7 @@ pub use futures_type::FuturesTypes;
 pub use margin::Margin;
 pub use orders::Order;
 pub use position::Position;
-
-use std::fmt::Formatter;
+pub use utils::round;
 pub(crate) use utils::{max, min};
 pub(crate) use validator::Validator;
 
@@ -112,35 +112,3 @@ impl OrderType {
         }
     }
 }
-
-#[derive(Debug, Clone, Copy, Serialize, Deserialize)]
-/// Defines the two fee types for different types of orders
-pub enum FeeType {
-    /// The fee for passive maker orders such as limit order
-    Maker,
-    /// The fee for aggressive taker orders such as market and stop loss order
-    Taker,
-}
-
-/// round a value to a given precision of decimal places
-/// used in tests
-#[inline(always)]
-pub fn round(val: f64, prec: i32) -> f64 {
-    ((val * 10.0_f64.powi(prec)).round()) / 10.0_f64.powi(prec)
-}
-
-#[cfg(test)]
-mod tests {
-    use super::*;
-
-    #[test]
-    fn test_round() {
-        assert_eq!(round(0.111111, 0), 0.0);
-        assert_eq!(round(0.111111, 1), 0.1);
-        assert_eq!(round(0.111111, 2), 0.11);
-        assert_eq!(round(0.111111, 3), 0.111);
-        assert_eq!(round(0.111111, 4), 0.1111);
-        assert_eq!(round(0.111111, 5), 0.11111);
-        assert_eq!(round(0.111111, 6), 0.111111);
-    }
-}
