@@ -1,5 +1,7 @@
-use crate::limit_order_margin::order_margin;
-use crate::{max, min, Account, FuturesTypes, Order, OrderError, Side};
+use crate::{
+    limit_order_margin::order_margin, max, min, Account, AccountTracker, FuturesTypes, Order,
+    OrderError, Side,
+};
 
 #[derive(Clone, Debug, Default)]
 /// Used for validating orders
@@ -37,9 +39,13 @@ impl Validator {
 
     /// Check if market order is correct
     /// # Returns
-    /// debited and credited account balance deltas, if order valid, OrderError otherwise
-    #[must_use]
-    pub(crate) fn validate_market_order(&self, o: &Order, acc: &Account) -> Result<(), OrderError> {
+    /// debited and credited account balance deltas, if order valid, OrderError
+    /// otherwise
+    pub(crate) fn validate_market_order<A: AccountTracker>(
+        &self,
+        o: &Order,
+        acc: &Account<A>,
+    ) -> Result<(), OrderError> {
         let (debit, credit) = self.order_cost_market(o, acc);
         debug!("validate_market_order debit: {}, credit: {}", debit, credit);
 
@@ -53,8 +59,11 @@ impl Validator {
     /// Check if a limit order is correct
     /// # Returns
     /// order margin if order is valid, OrderError otherwise
-    #[must_use]
-    pub(crate) fn validate_limit_order(&self, o: &Order, acc: &Account) -> Result<f64, OrderError> {
+    pub(crate) fn validate_limit_order<A: AccountTracker>(
+        &self,
+        o: &Order,
+        acc: &Account<A>,
+    ) -> Result<f64, OrderError> {
         // validate order price
         match o.side() {
             Side::Buy => {
@@ -87,12 +96,8 @@ impl Validator {
     /// # Returns
     /// debited and credited account balance delta
     #[must_use]
-    fn order_cost_market(&self, order: &Order, acc: &Account) -> (f64, f64) {
-        debug!(
-            "order_cost_market: order: {:?},\nacc.position: {:?}",
-            order,
-            acc.position()
-        );
+    fn order_cost_market<A: AccountTracker>(&self, order: &Order, acc: &Account<A>) -> (f64, f64) {
+        debug!("order_cost_market: order: {:?},\nacc.position: {:?}", order, acc.position());
 
         let pos_size = acc.position().size();
 
@@ -129,15 +134,15 @@ impl Validator {
         };
         match self.futures_type {
             FuturesTypes::Linear => {
-                // the values fee, debit and credit have to be converted from denoted in BASE currency
-                // to being denoted in QUOTE currency
+                // the values fee, debit and credit have to be converted from denoted in BASE
+                // currency to being denoted in QUOTE currency
                 fee *= price;
                 debit *= price;
                 credit *= price;
             }
             FuturesTypes::Inverse => {
-                // the values fee, debit and credit have to be converted from denoted in QUOTE currency
-                // to being denoted in BASE currency
+                // the values fee, debit and credit have to be converted from denoted in QUOTE
+                // currency to being denoted in BASE currency
                 fee /= price;
                 debit /= price;
                 credit /= price;
@@ -151,12 +156,9 @@ impl Validator {
     /// # Returns
     /// debited and credited account balance delta
     #[must_use]
-    fn limit_order_margin_cost(&self, order: &Order, acc: &Account) -> f64 {
+    fn limit_order_margin_cost<A: AccountTracker>(&self, order: &Order, acc: &Account<A>) -> f64 {
         let mut orders = acc.active_limit_orders().clone();
-        debug!(
-            "limit_order_margin_cost: order: {:?}, active_limit_orders: {:?}",
-            order, orders
-        );
+        debug!("limit_order_margin_cost: order: {:?}, active_limit_orders: {:?}", order, orders);
         orders.insert(order.id(), *order);
         let needed_order_margin = order_margin(
             orders.values(),
@@ -182,7 +184,7 @@ impl Validator {
 #[cfg(test)]
 mod tests {
     use super::*;
-    use crate::FuturesTypes;
+    use crate::{FuturesTypes, NoAccountTracker};
 
     #[test]
     fn validate_inverse_futures_market_order_without_position() {
@@ -193,7 +195,7 @@ mod tests {
         validator.update(100.0, 101.0);
 
         for leverage in [1.0, 2.0, 3.0, 4.0, 5.0] {
-            let acc = Account::new(leverage, 1.0, futures_type);
+            let acc = Account::new(NoAccountTracker::default(), leverage, 1.0, futures_type);
 
             let o = Order::market(Side::Buy, 40.0 * leverage).unwrap();
             validator.validate_market_order(&o, &acc).unwrap();
@@ -221,7 +223,7 @@ mod tests {
             debug!("testing with leverage: {}", leverage);
 
             // with long position
-            let mut acc = Account::new(leverage, 1.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), leverage, 1.0, futures_type);
             acc.change_position(Side::Buy, 50.0 * leverage, 101.0);
 
             let o = Order::market(Side::Buy, 49.0 * leverage).unwrap();
@@ -250,7 +252,7 @@ mod tests {
             debug!("leverage: {}", leverage);
 
             // with short position
-            let mut acc = Account::new(leverage, 1.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), leverage, 1.0, futures_type);
             acc.change_position(Side::Sell, 50.0 * leverage, 100.0);
 
             let o = Order::market(Side::Buy, 149.0 * leverage).unwrap();
@@ -279,7 +281,7 @@ mod tests {
             debug!("leverage: {}", leverage);
 
             // with buy limit order
-            let mut acc = Account::new(leverage, 1.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), leverage, 1.0, futures_type);
             let mut o = Order::limit(Side::Buy, 100.0, 50.0 * leverage).unwrap();
             o.set_id(1); // different id from test orders
             let order_margin = validator.validate_limit_order(&o, &acc).unwrap();
@@ -298,7 +300,7 @@ mod tests {
             assert!(validator.validate_market_order(&o, &acc).is_err());
 
             // with sell limit order
-            let mut acc = Account::new(leverage, 1.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), leverage, 1.0, futures_type);
             let mut o = Order::limit(Side::Sell, 100.0, 50.0 * leverage).unwrap();
             o.set_id(2); // different id from test orders
             let order_margin = validator.validate_limit_order(&o, &acc).unwrap();
@@ -327,7 +329,7 @@ mod tests {
         validator.update(100.0, 101.0);
 
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
-            let acc = Account::new(l, 1.0, futures_type);
+            let acc = Account::new(NoAccountTracker::default(), l, 1.0, futures_type);
 
             let o = Order::limit(Side::Buy, 100.0, 99.0 * l).unwrap();
             validator.validate_limit_order(&o, &acc).unwrap();
@@ -353,7 +355,7 @@ mod tests {
 
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             // with long position
-            let mut acc = Account::new(l, 1.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), l, 1.0, futures_type);
             acc.change_position(Side::Buy, 50.0 * l, 101.0);
 
             let o = Order::limit(Side::Buy, 100.0, 49.0 * l).unwrap();
@@ -381,7 +383,7 @@ mod tests {
 
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             // with short position
-            let mut acc = Account::new(l, 1.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), l, 1.0, futures_type);
             acc.change_position(Side::Sell, 50.0 * l, 100.0);
 
             let o = Order::limit(Side::Buy, 100.0, 99.0 * l).unwrap();
@@ -410,7 +412,7 @@ mod tests {
             debug!("leverage: {}", l);
 
             // with open buy order
-            let mut acc = Account::new(l, 1.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), l, 1.0, futures_type);
             let mut o = Order::limit(Side::Buy, 100.0, 50.0 * l).unwrap();
             o.set_id(1); // different id from test orders
             let order_margin = validator.validate_limit_order(&o, &acc).unwrap();
@@ -442,7 +444,7 @@ mod tests {
             debug!("leverage: {}", l);
 
             // with open sell order
-            let mut acc = Account::new(l, 1.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), l, 1.0, futures_type);
             let mut o = Order::limit(Side::Sell, 101.0, 50.0 * l).unwrap();
             o.set_id(1); // different id from test orders
             let order_margin = validator.validate_limit_order(&o, &acc).unwrap();
@@ -474,7 +476,7 @@ mod tests {
             debug!("leverage: {}", l);
 
             // with mixed limit orders
-            let mut acc = Account::new(l, 1.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), l, 1.0, futures_type);
             let mut o = Order::limit(Side::Buy, 100.0, 50.0 * l).unwrap();
             o.set_id(1); // different id from test orders
             let order_margin = validator.validate_limit_order(&o, &acc).unwrap();
@@ -510,7 +512,7 @@ mod tests {
         let futures_type = FuturesTypes::Inverse;
         let mut validator = Validator::new(0.0002, 0.0006, futures_type);
         validator.update(100.0, 101.0);
-        let mut acc = Account::new(1.0, 1.0, futures_type);
+        let mut acc = Account::new(NoAccountTracker::default(), 1.0, 1.0, futures_type);
 
         for i in (0..100).step_by(2) {
             // with mixed limit orders
@@ -541,7 +543,7 @@ mod tests {
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             debug!("leverage: {}", l);
 
-            let acc = Account::new(l, 100.0, futures_type);
+            let acc = Account::new(NoAccountTracker::default(), l, 100.0, futures_type);
 
             let o = Order::limit(Side::Buy, 100.0, 0.5 * l).unwrap();
             assert_eq!(validator.limit_order_margin_cost(&o, &acc), 50.0);
@@ -566,7 +568,7 @@ mod tests {
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             debug!("leverage: {}", l);
 
-            let mut acc = Account::new(l, 100.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), l, 100.0, futures_type);
             acc.change_position(Side::Buy, 0.5 * l, 100.0);
 
             let o = Order::limit(Side::Buy, 100.0, 0.5 * l).unwrap();
@@ -592,7 +594,7 @@ mod tests {
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             debug!("leverage: {}", l);
 
-            let mut acc = Account::new(l, 100.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), l, 100.0, futures_type);
             acc.change_position(Side::Sell, 0.5 * l, 100.0);
 
             let o = Order::limit(Side::Buy, 100.0, 0.5 * l).unwrap();
@@ -618,7 +620,7 @@ mod tests {
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             debug!("leverage: {}", l);
 
-            let mut acc = Account::new(l, 100.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), l, 100.0, futures_type);
             let mut o = Order::limit(Side::Buy, 100.0, 0.5 * l).unwrap();
             o.set_id(1); // different id from test orders
             let order_margin = validator.validate_limit_order(&o, &acc).unwrap();
@@ -647,7 +649,7 @@ mod tests {
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             debug!("leverage: {}", l);
 
-            let mut acc = Account::new(l, 100.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), l, 100.0, futures_type);
             let mut o = Order::limit(Side::Sell, 100.0, 0.5 * l).unwrap();
             o.set_id(1); // different id from test orders
             let order_margin = validator.validate_limit_order(&o, &acc).unwrap();
@@ -676,7 +678,7 @@ mod tests {
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             debug!("leverage: {}", l);
 
-            let mut acc = Account::new(l, 100.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), l, 100.0, futures_type);
             let mut o = Order::limit(Side::Buy, 100.0, 0.5 * l).unwrap();
             o.set_id(1); // different id from test orders
             let order_margin = validator.validate_limit_order(&o, &acc).unwrap();
@@ -709,7 +711,7 @@ mod tests {
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             debug!("leverage: {}", l);
 
-            let mut acc = Account::new(l, 100.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), l, 100.0, futures_type);
             acc.change_position(Side::Buy, 0.5 * l, 100.0);
             let mut o = Order::limit(Side::Buy, 100.0, 0.5 * l).unwrap();
             o.set_id(1); // different id from test orders
@@ -739,7 +741,7 @@ mod tests {
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             debug!("leverage: {}", l);
 
-            let mut acc = Account::new(l, 100.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), l, 100.0, futures_type);
             acc.change_position(Side::Buy, 0.5 * l, 100.0);
             let mut o = Order::limit(Side::Sell, 100.0, 0.5 * l).unwrap();
             o.set_id(1); // different id from test orders
@@ -769,7 +771,7 @@ mod tests {
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             debug!("leverage: {}", l);
 
-            let mut acc = Account::new(l, 100.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), l, 100.0, futures_type);
             acc.change_position(Side::Buy, 0.5 * l, 100.0);
             let mut o = Order::limit(Side::Sell, 100.0, 0.5 * l).unwrap();
             o.set_id(1); // different id from test orders
@@ -803,7 +805,7 @@ mod tests {
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             debug!("leverage: {}", l);
 
-            let mut acc = Account::new(l, 100.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), l, 100.0, futures_type);
             acc.change_position(Side::Sell, 0.5 * l, 100.0);
             let mut o = Order::limit(Side::Buy, 100.0, 0.5 * l).unwrap();
             o.set_id(1); // different id from test orders
@@ -833,7 +835,7 @@ mod tests {
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             debug!("leverage: {}", l);
 
-            let mut acc = Account::new(l, 100.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), l, 100.0, futures_type);
             acc.change_position(Side::Sell, 0.5 * l, 100.0);
             let mut o = Order::limit(Side::Sell, 100.0, 0.5 * l).unwrap();
             o.set_id(1); // different id from test orders
@@ -863,7 +865,7 @@ mod tests {
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             debug!("leverage: {}", l);
 
-            let mut acc = Account::new(l, 100.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), l, 100.0, futures_type);
             acc.change_position(Side::Sell, 0.5 * l, 100.0);
             let mut o = Order::limit(Side::Sell, 100.0, 0.5 * l).unwrap();
             o.set_id(1); // different id from test orders
@@ -897,7 +899,7 @@ mod tests {
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             debug!("leverage: {}", l);
 
-            let acc = Account::new(l, 1.0, futures_type);
+            let acc = Account::new(NoAccountTracker::default(), l, 1.0, futures_type);
 
             let o = Order::limit(Side::Buy, 100.0, 50.0 * l).unwrap();
             assert_eq!(validator.limit_order_margin_cost(&o, &acc), 0.5);
@@ -922,7 +924,7 @@ mod tests {
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             debug!("leverage: {}", l);
 
-            let mut acc = Account::new(l, 1.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), l, 1.0, futures_type);
             acc.change_position(Side::Buy, 50.0 * l, 100.0);
 
             let o = Order::limit(Side::Buy, 100.0, 50.0 * l).unwrap();
@@ -948,7 +950,7 @@ mod tests {
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             debug!("leverage: {}", l);
 
-            let mut acc = Account::new(l, 1.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), l, 1.0, futures_type);
             acc.change_position(Side::Sell, 50.0 * l, 100.0);
 
             let o = Order::limit(Side::Buy, 100.0, 50.0 * l).unwrap();
@@ -974,7 +976,7 @@ mod tests {
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             debug!("leverage: {}", l);
 
-            let mut acc = Account::new(l, 1.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), l, 1.0, futures_type);
             let mut o = Order::limit(Side::Buy, 100.0, 50.0 * l).unwrap();
             o.set_id(1); // different id from test orders
             let order_margin = validator.validate_limit_order(&o, &acc).unwrap();
@@ -1003,7 +1005,7 @@ mod tests {
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             debug!("leverage: {}", l);
 
-            let mut acc = Account::new(l, 1.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), l, 1.0, futures_type);
             let mut o = Order::limit(Side::Sell, 100.0, 50.0 * l).unwrap();
             o.set_id(1); // different id from test orders
             let order_margin = validator.validate_limit_order(&o, &acc).unwrap();
@@ -1032,7 +1034,7 @@ mod tests {
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             debug!("leverage: {}", l);
 
-            let mut acc = Account::new(l, 1.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), l, 1.0, futures_type);
             let mut o = Order::limit(Side::Buy, 100.0, 50.0 * l).unwrap();
             o.set_id(1); // different id from test orders
             let order_margin = validator.validate_limit_order(&o, &acc).unwrap();
@@ -1065,7 +1067,7 @@ mod tests {
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             debug!("leverage: {}", l);
 
-            let mut acc = Account::new(l, 1.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), l, 1.0, futures_type);
             acc.change_position(Side::Buy, 50.0 * l, 100.0);
             let mut o = Order::limit(Side::Buy, 100.0, 50.0 * l).unwrap();
             o.set_id(1); // different id from test orders
@@ -1095,7 +1097,7 @@ mod tests {
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             debug!("leverage: {}", l);
 
-            let mut acc = Account::new(l, 1.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), l, 1.0, futures_type);
             acc.change_position(Side::Buy, 50.0 * l, 100.0);
             let mut o = Order::limit(Side::Sell, 100.0, 50.0 * l).unwrap();
             o.set_id(1); // different id from test orders
@@ -1125,7 +1127,7 @@ mod tests {
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             debug!("leverage: {}", l);
 
-            let mut acc = Account::new(l, 1.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), l, 1.0, futures_type);
             acc.change_position(Side::Buy, 50.0 * l, 100.0);
             let mut o = Order::limit(Side::Sell, 100.0, 50.0 * l).unwrap();
             o.set_id(1); // different id from test orders
@@ -1159,7 +1161,7 @@ mod tests {
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             debug!("leverage: {}", l);
 
-            let mut acc = Account::new(l, 1.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), l, 1.0, futures_type);
             acc.change_position(Side::Sell, 50.0 * l, 100.0);
             let mut o = Order::limit(Side::Buy, 100.0, 50.0 * l).unwrap();
             o.set_id(1); // different id from test orders
@@ -1189,7 +1191,7 @@ mod tests {
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             debug!("leverage: {}", l);
 
-            let mut acc = Account::new(l, 1.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), l, 1.0, futures_type);
             acc.change_position(Side::Sell, 50.0 * l, 100.0);
             let mut o = Order::limit(Side::Sell, 100.0, 50.0 * l).unwrap();
             o.set_id(1); // different id from test orders
@@ -1219,7 +1221,7 @@ mod tests {
         for l in [1.0, 2.0, 3.0, 4.0, 5.0] {
             debug!("leverage: {}", l);
 
-            let mut acc = Account::new(l, 1.0, futures_type);
+            let mut acc = Account::new(NoAccountTracker::default(), l, 1.0, futures_type);
             acc.change_position(Side::Sell, 50.0 * l, 100.0);
             let mut o = Order::limit(Side::Sell, 100.0, 50.0 * l).unwrap();
             o.set_id(1); // different id from test orders
